==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/resolver/impl/$CreateFrequencyDrillDownSegmentSnapshotMutationResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
final public class $CreateFrequencyDrillDownSegmentSnapshotMutationResolver implements CreateFrequencyDrillDownSegmentSnapshotMutationResolver {

    private GrowingIOConfig growingIOConfig;

    public $CreateFrequencyDrillDownSegmentSnapshotMutationResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $CreateFrequencyDrillDownSegmentSnapshotMutationResolver() {}

    @javax.validation.constraints.NotNull
    @Override
    public DrillDownSegmentSnapshotReplyDto createFrequencyDrillDownSegmentSnapshot(String projectId, FrequencyDrillDownSegmentInputDto frequencyDrillDownSegment) throws Exception {
        CreateFrequencyDrillDownSegmentSnapshotMutationRequest request = new CreateFrequencyDrillDownSegmentSnapshotMutationRequest();
        List<String> keys = Arrays.asList("projectId", "frequencyDrillDownSegment");
        List<?> values = Arrays.asList(projectId, frequencyDrillDownSegment);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        DrillDownSegmentSnapshotReplyResponseProjection projection = new DrillDownSegmentSnapshotReplyResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        CreateFrequencyDrillDownSegmentSnapshotMutationResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, CreateFrequencyDrillDownSegmentSnapshotMutationResponse.class);
        return result.createFrequencyDrillDownSegmentSnapshot();
    }

}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/resolver/impl/$CreateFrequencyDrillDownSegmentSnapshotMutationResolver.java <==
package io.growing.graphql.resolver.impl;

import com.kobylynskyi.graphql.codegen.extension.GrowingIOConfig;
import com.kobylynskyi.graphql.codegen.extension.utils.JavaCollectionUtils;
import com.kobylynskyi.graphql.codegen.extension.utils.OkHttpUtils;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLRequest;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import io.growing.graphql.resolver.*;
import io.growing.graphql.model.*;

@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
final public class $CreateFrequencyDrillDownSegmentSnapshotMutationResolver implements CreateFrequencyDrillDownSegmentSnapshotMutationResolver {

    private GrowingIOConfig growingIOConfig;

    public $CreateFrequencyDrillDownSegmentSnapshotMutationResolver(GrowingIOConfig growingIOConfig) {
        this.growingIOConfig = growingIOConfig;
    }

    private $CreateFrequencyDrillDownSegmentSnapshotMutationResolver() {}

    @javax.validation.constraints.NotNull
    @Override
    public DrillDownSegmentSnapshotReplyDto createFrequencyDrillDownSegmentSnapshot(String projectId, FrequencyDrillDownSegmentInputDto frequencyDrillDownSegment) throws Exception {
        CreateFrequencyDrillDownSegmentSnapshotMutationRequest request = new CreateFrequencyDrillDownSegmentSnapshotMutationRequest();
        List<String> keys = Arrays.asList("projectId", "frequencyDrillDownSegment");
        List<?> values = Arrays.asList(projectId, frequencyDrillDownSegment);
        Map<String, ?> parameters = JavaCollectionUtils.listToMap(keys, values);
        request.getInput().putAll(parameters);
        DrillDownSegmentSnapshotReplyResponseProjection projection = new DrillDownSegmentSnapshotReplyResponseProjection().all$(growingIOConfig.getResponseProjectionMaxDepth());
        GraphQLRequest graphQLRequest = new GraphQLRequest(request, projection);
        CreateFrequencyDrillDownSegmentSnapshotMutationResponse result = OkHttpUtils.executeGraphQLRemote(growingIOConfig, graphQLRequest, CreateFrequencyDrillDownSegmentSnapshotMutationResponse.class);
        return result.createFrequencyDrillDownSegmentSnapshot();
    }

}
